import pytest
from io import StringIO
import sys
sys.path.append('src')

from heyyou.main import heyyou

def test_heyyou_default_english():
    sys.argv = ['heyyou']  # Simulating no language code argument passed
    captured_output = StringIO()
    sys.stdout = captured_output
    heyyou()
    sys.stdout = sys.__stdout__
    assert captured_output.getvalue().strip() == 'Hey, You!'

def test_heyyou_spanish():
    sys.argv = ['heyyou', 'ES']  # Simulating 'ES' language code argument passed
    captured_output = StringIO()
    sys.stdout = captured_output
    heyyou()
    sys.stdout = sys.__stdout__
    assert captured_output.getvalue().strip() == '¡Hola, tú!'

# Add more test cases for other language codes as needed...



import sys

def heyyou():
    if len(sys.argv) > 1:
        language_code = sys.argv[1]
    else:
        language_code = 'EN'

    greetings = {
        'EN': 'Hey, You!',
        'ES': '¡Hola, tú!',
        'FR': 'Salut, toi!',
        'DE': 'Hallo, du!',
        'IT': 'Ciao, tu!',
        'MS': 'Hai, awak!',
        'ZH': '嘿，你！',
        'JA': 'やあ、君！',
        'KO': '안녕, 너!',
        'RU': 'Привет, ты!',
        'AR': 'مرحبا أنت!',
        'HI': 'नमस्ते, तुम!',
    }

    if language_code and language_code in greetings:
        print(greetings[language_code])

    else:
        print("Language code provided invalid or unsupported.")
